@@ -43,6 +43,7 @@ from transiter.db import dbconnection, models
 from transiter.db.queries import feedqueries
 from transiter.executor import celeryapp
 from transiter.parse import parser, gtfsstatic, gtfsrealtime, TransiterParser
+from transiter.scheduler import client
 
 logger = logging.getLogger(__name__)
 
@@ -93,10 +94,11 @@ def execute_feed_update(
     else:
         actions = _REGULAR_UPDATE_ACTIONS
 
+    stats = None
     exception = None
     for action in actions:
         try:
-            action(context)
+            stats = action(context)
         except Exception as e:
             logger.exception("Exception encountered during update")
             exception_type_to_outcome = getattr(
@@ -132,6 +134,12 @@ def execute_feed_update(
             context.feed_update.feed_pk,
         )
     )
+    client.feed_update_callback(
+        context.feed_update.feed_pk,
+        context.feed_update.status,
+        context.feed_update.result,
+        stats.entity_type_to_num_in_db() if stats is not None else {},
+    )
     return context.feed_update, exception
 
 
@@ -261,16 +269,17 @@ def _load_content_into_parser(context: _UpdateContext):
 def _import(context: _UpdateContext):
     feed_update = context.feed_update
     with dbconnection.inline_unit_of_work() as session:
-        (
-            feed_update.num_added_entities,
-            feed_update.num_updated_entities,
-            feed_update.num_deleted_entities,
-        ) = import_.run_import(feed_update.pk, context.parser)
+        stats = import_.run_import(feed_update.pk, context.parser)
+
+        feed_update.num_added_entities = stats.num_added()
+        feed_update.num_updated_entities = stats.num_updated()
+        feed_update.num_deleted_entities = stats.num_deleted()
         feed_update.num_parsed_entities = -1
         feed_update.status = models.FeedUpdate.Status.SUCCESS
         feed_update.result = models.FeedUpdate.Result.UPDATED
+
         session.merge(feed_update)
-        return feed_update
+        return stats
 
 
 _REGULAR_UPDATE_ACTIONS = [
